@@ -1,7 +1,7 @@
 #!/bin/bash
 
 $(pwd)/msolve -f input_files/$file.ms -o test/diff/$file.res \
-      -P 2 -l 2 -t 1
+      -P 2 -d 0 -l 2 -t 1
 if [ $? -gt 0 ]; then
     exit 1
 fi
@@ -12,7 +12,7 @@ if [ $? -gt 0 ]; then
 fi
 
 $(pwd)/msolve -f input_files/$file.ms -o test/diff/$file.res \
-      -P 2 -l 2 -t 2
+      -P 2 -d 0 -l 2 -t 2
 if [ $? -gt 0 ]; then
     exit 21
 fi
@@ -23,7 +23,7 @@ if [ $? -gt 0 ]; then
 fi
 
 $(pwd)/msolve -f input_files/$file.ms -o test/diff/$file.res \
-      -P 2 -l 44 -t 1
+      -P 2 -d 0 -l 44 -t 1
 if [ $? -gt 0 ]; then
     exit 41
 fi
@@ -34,7 +34,7 @@ if [ $? -gt 0 ]; then
 fi
 
 $(pwd)/msolve -f input_files/$file.ms -o test/diff/$file.res \
-      -P 2 -l 44 -t 2
+      -P 2 -d 0 -l 44 -t 2
 if [ $? -gt 0 ]; then
     exit 61
 fi
